// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef AUDIOCDPLUGINS_VERSION_H
#define AUDIOCDPLUGINS_VERSION_H

#define AUDIOCDPLUGINS_VERSION_STRING "5.1.26041"
#define AUDIOCDPLUGINS_VERSION_MAJOR 5
#define AUDIOCDPLUGINS_VERSION_MINOR 1
#define AUDIOCDPLUGINS_VERSION_PATCH 26041
#define AUDIOCDPLUGINS_VERSION ((5<<16)|(1<<8)|(26041))

#endif
